@@ -1,7 +1,7 @@
 package Text::ANSITable;
 
-our $DATE = '2014-12-05'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2014-12-11'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use Log::Any '$log';
@@ -162,8 +162,9 @@ has header_bgcolor => (
     is      => 'rw',
 );
 
-with 'SHARYANTO::Role::ColorTheme';
-with 'SHARYANTO::Role::BorderStyle';
+with 'Border::Style::Role';
+with 'Color::Theme::Role::ANSI';
+with 'Term::App::Role::Attrs';
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -203,7 +204,7 @@ sub BUILD {
     unless ($self->{border_style}) {
         my $bs;
 
-        my $use_utf8 = $self->{use_utf8};
+        my $use_utf8 = $self->use_utf8;
 
         # even though Term::Detect::Software decides that linux virtual console
         # does not support unicode, it actually can display some uni characters
@@ -230,7 +231,7 @@ sub BUILD {
             $bs = $ENV{ANSITABLE_BORDER_STYLE};
         } elsif ($use_utf8) {
             $bs //= 'Default::bricko';
-        } elsif ($self->{use_box_chars}) {
+        } elsif ($self->use_box_chars) {
             $bs = 'Default::singleo_boxchar';
         } else {
             $bs = 'Default::singleo_ascii';
@@ -244,9 +245,9 @@ sub BUILD {
         my $ct;
         if (defined $ENV{ANSITABLE_COLOR_THEME}) {
             $ct = $ENV{ANSITABLE_COLOR_THEME};
-        } elsif ($self->{use_color}) {
+        } elsif ($self->use_color) {
             my $bg = $self->detect_terminal->{default_bgcolor} // '';
-            if ($self->{color_depth} >= 2**24) {
+            if ($self->color_depth >= 2**24) {
                 $ct = 'Default::default_gradation' .
                     ($bg eq 'ffffff' ? '_whitebg' : '');
             } else {
@@ -1339,9 +1340,9 @@ sub _get_header_cell_lines {
 
     my $fgcolor;
     if (defined $self->{header_fgcolor}) {
-        $fgcolor = $self->themecol2ansi($self->{header_fgcolor});
+        $fgcolor = $self->theme_color_to_ansi($self->{header_fgcolor});
     } elsif (defined $self->{cell_fgcolor}) {
-        $fgcolor = $self->themecol2ansi($self->{cell_fgcolor});
+        $fgcolor = $self->theme_color_to_ansi($self->{cell_fgcolor});
     #} elsif (defined $self->{_draw}{fcol_detect}[$i]{fgcolor}) {
     #    $fgcolor = $self->themecol2ansi($self->{_draw}{fcol_detect}[$i]{fgcolor});
     } elsif (defined $ct->{colors}{header}) {
@@ -1354,14 +1355,14 @@ sub _get_header_cell_lines {
 
     my $bgcolor;
     if (defined $self->{header_bgcolor}) {
-        $bgcolor = $self->themecol2ansi($self->{header_bgcolor},
-                                        undef, 1);
+        $bgcolor = $self->theme_color_to_ansi($self->{header_bgcolor},
+                                              undef, 1);
     } elsif (defined $self->{cell_bgcolor}) {
-        $bgcolor = $self->themecol2ansi($self->{cell_bgcolor},
-                                        undef, 1);
+        $bgcolor = $self->theme_color_to_ansi($self->{cell_bgcolor},
+                                              undef, 1);
     } elsif (defined $self->{_draw}{fcol_detect}[$i]{bgcolor}) {
-        $fgcolor = $self->themecol2ansi($self->{_draw}{fcol_detect}[$i]{bgcolor},
-                                        undef, 1);
+        $fgcolor = $self->theme_color_to_ansi($self->{_draw}{fcol_detect}[$i]{bgcolor},
+                                              undef, 1);
     } elsif (defined $ct->{colors}{header_bg}) {
         $bgcolor = $self->get_theme_color_as_ansi('header_bg');
     } elsif (defined $ct->{colors}{cell_bg}) {
@@ -1410,15 +1411,15 @@ sub _get_data_cell_lines {
     my $tmp;
     my $fgcolor;
     if (defined ($tmp = $self->get_eff_cell_style($oy, $x, 'fgcolor'))) {
-        $fgcolor = $self->themecol2ansi($tmp, $args);
+        $fgcolor = $self->theme_color_to_ansi($tmp, $args);
     } elsif (defined ($tmp = $self->get_eff_row_style($oy, 'fgcolor'))) {
-        $fgcolor = $self->themecol2ansi($tmp, $args);
+        $fgcolor = $self->theme_color_to_ansi($tmp, $args);
     } elsif (defined ($tmp = $self->get_eff_column_style($x, 'fgcolor'))) {
-        $fgcolor = $self->themecol2ansi($tmp, $args);
+        $fgcolor = $self->theme_color_to_ansi($tmp, $args);
     } elsif (defined ($tmp = $self->{cell_fgcolor})) {
-        $fgcolor = $self->themecol2ansi($tmp, $args);
+        $fgcolor = $self->theme_color_to_ansi($tmp, $args);
     } elsif (defined ($tmp = $self->{_draw}{fcol_detect}[$x]{fgcolor})) {
-        $fgcolor = $self->themecol2ansi($tmp, $args);
+        $fgcolor = $self->theme_color_to_ansi($tmp, $args);
     } elsif (defined $ct->{colors}{cell}) {
         $fgcolor = $self->get_theme_color_as_ansi('cell', $args);
     } else {
@@ -1427,15 +1428,15 @@ sub _get_data_cell_lines {
 
     my $bgcolor;
     if (defined ($tmp = $self->get_eff_cell_style($oy, $x, 'bgcolor'))) {
-        $bgcolor = $self->themecol2ansi($tmp, $args, 1);
+        $bgcolor = $self->theme_color_to_ansi($tmp, $args, 1);
     } elsif (defined ($tmp = $self->get_eff_row_style($oy, 'bgcolor'))) {
-        $bgcolor = $self->themecol2ansi($tmp, $args, 1);
+        $bgcolor = $self->theme_color_to_ansi($tmp, $args, 1);
     } elsif (defined ($tmp = $self->get_eff_column_style($x, 'bgcolor'))) {
-        $bgcolor = $self->themecol2ansi($tmp, $args, 1);
+        $bgcolor = $self->theme_color_to_ansi($tmp, $args, 1);
     } elsif (defined ($tmp = $self->{cell_bgcolor})) {
-        $bgcolor = $self->themecol2ansi($tmp, $args, 1);
+        $bgcolor = $self->theme_color_to_ansi($tmp, $args, 1);
     } elsif (defined ($tmp = $self->{_draw}{fcol_detect}[$x]{bgcolor})) {
-        $bgcolor = $self->themecol2ansi($tmp, $args, 1);
+        $bgcolor = $self->theme_color_to_ansi($tmp, $args, 1);
     } elsif (defined $ct->{colors}{cell_bg}) {
         $bgcolor = $self->get_theme_color_as_ansi('cell_bg', $args);
     } else {
@@ -1642,7 +1643,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.35 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2014-12-05.
+This document describes version 0.36 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2014-12-11.
 
 =head1 SYNOPSIS
 
@@ -1739,7 +1740,7 @@ default.
 To create a new border style, create a module under
 C<Text::ANSITable::BorderStyle::>. Please see one of the existing border style
 modules for example, like L<Text::ANSITable::BorderStyle::Default>. For more
-about border styles, refer to L<SHARYANTO::Role::BorderStyle>.
+about border styles, refer to L<Border::Style::Role>.
 
 =head1 COLOR THEMES
 
@@ -1764,7 +1765,7 @@ also set the C<ANSITABLE_COLOR_THEME> environment variable to set the default.
 To create a new color theme, create a module under
 C<Text::ANSITable::ColorTheme::>. Please see one of the existing color theme
 modules for example, like L<Text::ANSITable::ColorTheme::Default>. For more
-about color themes, refer to L<SHARYANTO::Role::ColorTheme>.
+about color themes, refer to L<Color::Theme::Role>.
 
 =head1 COLUMN WIDTHS
 
